@@ -7,6 +7,7 @@
   Copyright (c) 2001 Waldo Bastian <bastian@kde.org>
   Copyright (c) 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
   Copyright (c) 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
+  Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -27,12 +28,12 @@
 #include "addresseelineedit.h"
 #include "addresseelineedit_p.h"
 #include "Libkdepim/AddresseeLineEditUtil"
+#include "addresseelineeditmanager.h"
 #include "ldap/ldapclientsearch.h"
 
 #include <KContacts/VCardConverter>
 
 #include <Job>
-#include <QRegularExpression>
 #include <QUrl>
 #include <kconfiggroup.h>
 
@@ -71,7 +72,7 @@ using namespace KPIM;
 
 inline bool itemIsHeader(const QListWidgetItem *item)
 {
-    return item && !item->text().startsWith(QStringLiteral("     "));
+    return item && !item->text().startsWith(QLatin1String("     "));
 }
 
 // needs to be unique, but the actual name doesn't matter much
@@ -122,26 +123,11 @@ bool AddresseeLineEdit::expandIntern() const
     return d->expandIntern();
 }
 
-bool AddresseeLineEdit::groupsIsEmpty() const
-{
-    return d->groupsIsEmpty();
-}
-
 void AddresseeLineEdit::setExpandIntern(bool expand)
 {
     d->setExpandIntern(expand);
 }
 
-bool AddresseeLineEdit::autoGroupExpand() const
-{
-    return d->autoGroupExpand();
-}
-
-void AddresseeLineEdit::setAutoGroupExpand(bool autoGroupExpand)
-{
-    d->setAutoGroupExpand(autoGroupExpand);
-}
-
 void AddresseeLineEdit::setEnableBalooSearch(bool enable)
 {
     d->setEnableBalooSearch(enable);
@@ -239,12 +225,11 @@ void AddresseeLineEdit::insert(const QString &t)
     newText = KPIM::AddresseeLineEditUtil::adaptPasteMails(newText);
 
     QString contents = text();
-    int start_sel = 0;
     int pos = cursorPosition();
 
     if (hasSelectedText()) {
         // Cut away the selection.
-        start_sel = selectionStart();
+        int start_sel = selectionStart();
         pos = start_sel;
         contents = contents.left(start_sel) + contents.mid(start_sel + selectedText().length());
     }
@@ -313,9 +298,8 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
         KContacts::Addressee::List list;
         KContacts::VCardDrag::fromMimeData(md, list);
 
-        KContacts::Addressee::List::ConstIterator ait;
-        KContacts::Addressee::List::ConstIterator end(list.constEnd());
-        for (ait = list.constBegin(); ait != end; ++ait) {
+        const KContacts::Addressee::List::ConstIterator end(list.constEnd());
+        for (KContacts::Addressee::List::ConstIterator ait = list.constBegin(); ait != end; ++ait) {
             insertEmails((*ait).emails());
         }
     }
@@ -333,9 +317,7 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                 KContacts::Addressee addressee;
                 addressee.insertEmail(KEmailAddress::decodeMailtoUrl(url), true /* preferred */);
                 list += addressee;
-            }
-            // Otherwise, download the vCard to which the Url points
-            else {
+            } else { // Otherwise, download the vCard to which the Url points
                 KContacts::VCardConverter converter;
                 auto job = KIO::storedGet(url);
                 KJobWidgets::setWindow(job, parentWidget());
@@ -352,6 +334,8 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                             Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(group);
                             connect(expandJob, &Akonadi::ContactGroupExpandJob::result, this, &AddresseeLineEdit::groupExpandResult);
                             expandJob->start();
+                        } else {
+                            qCWarning(LIBKDEPIMAKONADI_LOG) << "Error during converting contactgroup " << error;
                         }
                     }
                 } else {
@@ -386,14 +370,14 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                 }
                 bool mailtoURL = false;
                 // append the mailto URLs
-                for (const QUrl &url : qAsConst(uriList)) {
+                for (const QUrl &url : uriList) {
                     if (url.scheme() == QLatin1String("mailto")) {
                         mailtoURL = true;
                         QString address;
                         address = QUrl::fromPercentEncoding(url.path().toLatin1());
                         address = KCodecs::decodeRFC2047String(address);
                         if (!contents.isEmpty()) {
-                            contents.append(QStringLiteral(", "));
+                            contents.append(QLatin1String(", "));
                         }
                         contents.append(address);
                     }
@@ -449,7 +433,7 @@ void AddresseeLineEdit::groupExpandResult(KJob *job)
 
     const KContacts::Addressee::List contacts = expandJob->contacts();
     for (const KContacts::Addressee &addressee : contacts) {
-        if (d->expandIntern() || text().isEmpty()) {
+        if (d->expandIntern() || text().trimmed().isEmpty()) {
             insertEmails(QStringList() << addressee.fullEmail());
         } else {
             Q_EMIT addAddress(addressee.fullEmail());
@@ -520,7 +504,10 @@ void AddresseeLineEdit::addContactGroup(const KContacts::ContactGroup &group, in
 
 void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight, int source, QString append)
 {
-    const QStringList emails = addr.emails();
+    const QStringList emails = AddresseeLineEditManager::self()->cleanupEmailList(addr.emails());
+    if (emails.isEmpty()) {
+        return;
+    }
     QStringList::ConstIterator it;
     int isPrefEmail = 1; //first in list is preferredEmail
     QStringList::ConstIterator end(emails.constEnd());
@@ -594,7 +581,6 @@ QMenu *AddresseeLineEdit::createStandardContextMenu()
     if (d->useCompletion()) {
         QAction *showOU = new QAction(i18n("Show Organization Unit for LDAP results"), menu);
         showOU->setCheckable(true);
-
         showOU->setChecked(d->showOU());
         connect(showOU, &QAction::triggered, d, &AddresseeLineEditPrivate::slotShowOUChanged);
         menu->addAction(showOU);
@@ -607,10 +593,10 @@ QMenu *AddresseeLineEdit::createStandardContextMenu()
     menu->addSeparator();
     QAction *act = menu->addAction(i18n("Automatically expand groups"));
     act->setCheckable(true);
-    act->setChecked(autoGroupExpand());
-    connect(act, &QAction::triggered, this, &AddresseeLineEdit::slotToggleExpandGroups);
+    act->setChecked(d->autoGroupExpand());
+    connect(act, &QAction::triggered, d, &AddresseeLineEditPrivate::slotToggleExpandGroups);
 
-    if (!groupsIsEmpty()) {
+    if (!d->groupsIsEmpty()) {
         act = menu->addAction(i18n("Expand Groups..."));
         connect(act, &QAction::triggered, this, &AddresseeLineEdit::expandGroups);
     }
@@ -630,33 +616,26 @@ void AddresseeLineEdit::configureCompletion()
     QScopedPointer<KPIM::CompletionConfigureDialog> dlg(new KPIM::CompletionConfigureDialog(this));
     dlg->setRecentAddresses(KPIM::RecentAddresses::self(recentAddressConfig())->addresses());
     dlg->setLdapClientSearch(ldapSearch());
-    dlg->setEmailBlackList(balooBlackList());
+    dlg->setEmailBlackList(KPIM::AddresseeLineEditManager::self()->balooBlackList());
     dlg->load();
     if (dlg->exec() && dlg) {
         if (dlg->recentAddressWasChanged()) {
             KPIM::RecentAddresses::self(recentAddressConfig())->clear();
             dlg->storeAddresses(recentAddressConfig());
             loadContacts();
-            updateBalooBlackList();
-            updateCompletionOrder();
         }
+        updateBalooBlackList();
+        updateCompletionOrder();
     }
     d->setCanDeleteLineEdit(true);
 }
 
-void AddresseeLineEdit::slotToggleExpandGroups()
-{
-    setAutoGroupExpand(!autoGroupExpand());
-    KConfigGroup group(KSharedConfig::openConfig(), "AddressLineEdit");
-    group.writeEntry("AutoGroupExpand", autoGroupExpand());
-}
-
 void AddresseeLineEdit::loadContacts()
 {
     const QString recentAddressGroupName = i18n("Recent Addresses");
     if (showRecentAddresses()) {
         const QStringList recent
-            = cleanupEmailList(KPIM::RecentAddresses::self(recentAddressConfig())->addresses());
+            = AddresseeLineEditManager::self()->cleanupEmailList(KPIM::RecentAddresses::self(recentAddressConfig())->addresses());
         QStringList::ConstIterator it = recent.constBegin();
         QString name, email;
 
@@ -667,8 +646,8 @@ void AddresseeLineEdit::loadContacts()
         const int idx = addCompletionSource(recentAddressGroupName, weight);
 
         QStringList::ConstIterator end = recent.constEnd();
+        KContacts::Addressee addr;
         for (; it != end; ++it) {
-            KContacts::Addressee addr;
             KEmailAddress::extractEmailAddressAndName(*it, email, name);
             name = KEmailAddress::quoteNameIfNecessary(name);
             if ((name[0] == QLatin1Char('"')) && (name[name.length() - 1] == QLatin1Char('"'))) {
@@ -833,7 +812,7 @@ bool KPIM::AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
 
             // when iterating forward, start at the currentindex, when backwards,
             // one up from our header, or at the end
-            uint j;
+            int j;
             if (keyEvent->key() == Qt::Key_Tab) {
                 j = currentIndex;
             } else {
@@ -906,11 +885,6 @@ KLDAP::LdapClientSearch *AddresseeLineEdit::ldapSearch() const
     return d->ldapSearch();
 }
 
-QStringList AddresseeLineEdit::balooBlackList() const
-{
-    return d->balooBlackList();
-}
-
 void AddresseeLineEdit::slotEditingFinished()
 {
     for (KJob *job : d->mightBeGroupJobs()) {
@@ -921,7 +895,7 @@ void AddresseeLineEdit::slotEditingFinished()
     d->mightBeGroupJobsClear();
     d->groupsClear();
 
-    if (!text().isEmpty() && enableAkonadiSearch()) {
+    if (!text().trimmed().isEmpty() && enableAkonadiSearch()) {
         const QStringList addresses = KEmailAddress::splitAddressList(text());
         for (const QString &address : addresses) {
             Akonadi::ContactGroupSearchJob *job = new Akonadi::ContactGroupSearchJob();
@@ -952,7 +926,7 @@ void AddresseeLineEdit::slotGroupSearchResult(KJob *job)
     d->addGroups(contactGroups);
     searchJob->deleteLater();
 
-    if (autoGroupExpand()) {
+    if (d->autoGroupExpand()) {
         expandGroups();
     }
 }
