@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,9 +16,9 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
+#include "addresseelineedit_p.h"
 #include "addressline/completionorder/completionordereditor.h"
 #include "addresseelineeditmanager.h"
-#include "addresseelineedit_p.h"
 #include "addresseelineedit.h"
 #include "kmailcompletion.h"
 #include "libkdepimakonadi_debug.h"
@@ -42,33 +43,31 @@
 #include <addressline/addresslineedit/baloocompletionemail.h>
 #include <akonadi/contact/contactsearchjob.h>
 
-namespace KPIM {
+using namespace KPIM;
 AddresseeLineEditPrivate::AddresseeLineEditPrivate(KPIM::AddresseeLineEdit *qq, bool enableCompletion)
     : QObject(qq)
     , q(qq)
-    , m_recentAddressConfig(nullptr)
-    , m_useCompletion(enableCompletion)
-    , m_completionInitialized(false)
-    , m_smartPaste(false)
-    , m_addressBookConnected(false)
-    , m_lastSearchMode(false)
-    , m_searchExtended(false)
-    , m_useSemicolonAsSeparator(false)
-    , m_showOU(false)
-    , m_enableBalooSearch(true)
-    , m_enableAkonadiSearch(true)
+    , mRecentAddressConfig(nullptr)
+    , mUseCompletion(enableCompletion)
+    , mCompletionInitialized(false)
+    , mSmartPaste(false)
+    , mLastSearchMode(false)
+    , mSearchExtended(false)
+    , mUseSemicolonAsSeparator(false)
+    , mEnableBalooSearch(true)
+    , mEnableAkonadiSearch(true)
     , mExpandIntern(true)
-    , mAutoGroupExpand(false)
     , mShowRecentAddresses(true)
     , mCanDeleteLineEdit(true)
 {
-    m_delayedQueryTimer.setSingleShot(true);
-    connect(&m_delayedQueryTimer, &QTimer::timeout, this, &AddresseeLineEditPrivate::slotTriggerDelayedQueries);
+    mDelayedQueryTimer = new QTimer(this);
+    mDelayedQueryTimer->setSingleShot(true);
+    connect(mDelayedQueryTimer, &QTimer::timeout, this, &AddresseeLineEditPrivate::slotTriggerDelayedQueries);
 }
 
 AddresseeLineEditPrivate::~AddresseeLineEditPrivate()
 {
-    if (AddresseeLineEditManager::self()->ldapSearch() && AddresseeLineEditManager::self()->addressLineEdit() == q) {
+    if (AddresseeLineEditManager::self()->addressLineEdit() == q) {
         AddresseeLineEditManager::self()->stopLDAPLookup();
     }
 }
@@ -105,50 +104,47 @@ public:
 
 void AddresseeLineEditPrivate::init()
 {
-    m_toolButton = new QToolButton(q);
-    m_toolButton->setVisible(false);
-    m_toolButton->setCursor(Qt::ArrowCursor);
+    if (mToolButton) {
+        return;
+    }
+    mToolButton = new QToolButton(q);
+    mToolButton->setVisible(false);
+    mToolButton->setCursor(Qt::ArrowCursor);
     const int size = q->sizeHint().height() - 5;
-    m_toolButton->setFixedSize(size, size);
+    mToolButton->setFixedSize(size, size);
     int padding = (q->sizeHint().height() - size) / 2;
-    m_toolButton->move(2, padding);
-    m_toolButton->setStyleSheet(QStringLiteral("QToolButton { border: none; }"));
-    connect(m_toolButton, &QToolButton::clicked, q, &AddresseeLineEdit::iconClicked);
+    mToolButton->move(2, padding);
+    mToolButton->setStyleSheet(QStringLiteral("QToolButton { border: none; }"));
+    connect(mToolButton, &QToolButton::clicked, q, &AddresseeLineEdit::iconClicked);
 
     if (!AddresseeLineEditManager::self()) {
         AddresseeLineEditManager::self()->completion()->setOrder(KCompletion::Weighted);
         AddresseeLineEditManager::self()->completion()->setIgnoreCase(true);
     }
 
-    if (m_useCompletion) {
+    if (mUseCompletion) {
         AddresseeLineEditManager::self()->initializeLdap();
         AddresseeLineEditManager::self()->setBalooCompletionSource(q->addCompletionSource(i18nc("@title:group", "Contacts found in your data"), -1));
-
         AddresseeLineEditManager::self()->updateLDAPWeights();
-        if (!m_completionInitialized) {
+
+        if (!mCompletionInitialized) {
             q->setCompletionObject(AddresseeLineEditManager::self()->completion(), false);
             connect(q, &KLineEdit::completion,
                     this, &AddresseeLineEditPrivate::slotCompletion);
-            connect(q, SIGNAL(returnPressed(QString)),
-                    this, SLOT(slotReturnPressed(QString)));
+            connect(q, &AddresseeLineEdit::returnPressed,
+                    this, &AddresseeLineEditPrivate::slotReturnPressed);
 
             KCompletionBox *box = q->completionBox();
-            connect(box, SIGNAL(activated(QString)),
-                    this, SLOT(slotPopupCompletion(QString)));
+            connect(box, QOverload<const QString &>::of(&KCompletionBox::activated),
+                    this, &AddresseeLineEditPrivate::slotPopupCompletion);
             connect(box, &KCompletionBox::userCancelled,
                     this, &AddresseeLineEditPrivate::slotUserCancelled);
             connect(AddresseeLineEditManager::self()->ldapTimer(), &QTimer::timeout, this, &AddresseeLineEditPrivate::slotStartLDAPLookup);
-            connect(AddresseeLineEditManager::self()->ldapSearch(), SIGNAL(searchData(KLDAP::LdapResult::List)),
-                    SLOT(slotLDAPSearchData(KLDAP::LdapResult::List)));
+            connect(AddresseeLineEditManager::self()->ldapSearch(), QOverload<const KLDAP::LdapResult::List &>::of(&KLDAP::LdapClientSearch::searchData),
+                    this, &AddresseeLineEditPrivate::slotLDAPSearchData);
 
-            m_completionInitialized = true;
+            mCompletionInitialized = true;
         }
-
-        KConfigGroup group(KSharedConfig::openConfig(), "AddressLineEdit");
-        m_showOU = group.readEntry("ShowOU", false);
-        mAutoGroupExpand = group.readEntry("AutoGroupExpand", false);
-
-        loadBalooBlackList();
     }
     connect(q, &AddresseeLineEdit::textCompleted, q, &AddresseeLineEdit::slotEditingFinished);
     connect(q, &AddresseeLineEdit::editingFinished, q, &AddresseeLineEdit::slotEditingFinished);
@@ -157,47 +153,26 @@ void AddresseeLineEditPrivate::init()
 void AddresseeLineEditPrivate::setIcon(const QIcon &icon, const QString &tooltip)
 {
     if (icon.isNull()) {
-        m_toolButton->setVisible(false);
+        mToolButton->setVisible(false);
         q->setStyleSheet(QString());
     } else {
-        m_toolButton->setIcon(icon);
-        m_toolButton->setToolTip(tooltip);
-        const int padding = m_toolButton->width() - q->style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
+        mToolButton->setIcon(icon);
+        mToolButton->setToolTip(tooltip);
+        const int padding = mToolButton->width() - q->style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
         q->setStyleSheet(QStringLiteral("QLineEdit { padding-left: %1px }").arg(padding));
-        m_toolButton->setVisible(true);
+        mToolButton->setVisible(true);
     }
 }
 
-QStringList AddresseeLineEdit::cleanupEmailList(const QStringList &inputList)
-{
-    return d->cleanupEmailList(inputList);
-}
-
-QStringList AddresseeLineEditPrivate::cleanupEmailList(const QStringList &inputList)
-{
-    KPIM::BalooCompletionEmail completionEmail;
-    completionEmail.setEmailList(inputList);
-    completionEmail.setBlackList(m_balooBlackList);
-    completionEmail.setExcludeDomain(m_domainExcludeList);
-    const QStringList listEmail = completionEmail.cleanupEmailList();
-    return listEmail;
-}
-
 void AddresseeLineEditPrivate::searchInBaloo()
 {
-    const QString trimmedString = m_searchString.trimmed();
+    const QString trimmedString = mSearchString.trimmed();
     Akonadi::Search::PIM::ContactCompleter com(trimmedString, 20);
-    const QStringList listEmail = cleanupEmailList(com.complete());
+    const QStringList listEmail = AddresseeLineEditManager::self()->cleanupEmailList(com.complete());
     for (const QString &email : listEmail) {
         addCompletionItem(email, 1, AddresseeLineEditManager::self()->balooCompletionSource());
     }
-    doCompletion(m_lastSearchMode);
-}
-
-void AddresseeLineEditPrivate::alternateColor()
-{
-    const KColorScheme colorScheme(QPalette::Active, KColorScheme::View);
-    m_alternateColor = colorScheme.background(KColorScheme::AlternateBackground).color();
+    doCompletion(mLastSearchMode);
 }
 
 void AddresseeLineEditPrivate::setCompletedItems(const QStringList &items, bool autoSuggest)
@@ -205,23 +180,20 @@ void AddresseeLineEditPrivate::setCompletedItems(const QStringList &items, bool
     KCompletionBox *completionBox = q->completionBox();
 
     if (!items.isEmpty()
-        && !(items.count() == 1 && m_searchString == items.first())) {
+        && !(items.count() == 1 && mSearchString == items.first())) {
         completionBox->clear();
         const int numberOfItems(items.count());
         for (int i = 0; i < numberOfItems; ++i) {
             QListWidgetItem *item = new QListWidgetItem(items.at(i), completionBox);
             if (!items.at(i).startsWith(s_completionItemIndentString)) {
-                if (!m_alternateColor.isValid()) {
-                    alternateColor();
-                }
                 item->setFlags(item->flags() & ~Qt::ItemIsSelectable);
-                item->setBackgroundColor(m_alternateColor);
+                item->setBackgroundColor(AddresseeLineEditManager::self()->alternateColor());
             }
             completionBox->addItem(item);
         }
         if (!completionBox->isVisible()) {
-            if (!m_searchString.isEmpty()) {
-                completionBox->setCancelledText(m_searchString);
+            if (!mSearchString.isEmpty()) {
+                completionBox->setCancelledText(mSearchString);
             }
             completionBox->popup();
             // we have to install the event filter after popup(), since that
@@ -241,7 +213,7 @@ void AddresseeLineEditPrivate::setCompletedItems(const QStringList &items, bool
         }
 
         if (autoSuggest) {
-            const int index = items.first().indexOf(m_searchString);
+            const int index = items.first().indexOf(mSearchString);
             const QString newText = items.first().mid(index);
             q->callSetUserSelection(false);
             q->callSetCompletedText(newText, true);
@@ -279,8 +251,8 @@ void AddresseeLineEditPrivate::addCompletionItem(const QString &string, int weig
 const QStringList KPIM::AddresseeLineEditPrivate::adjustedCompletionItems(bool fullSearch)
 {
     QStringList items = fullSearch
-                        ? AddresseeLineEditManager::self()->completion()->allMatches(m_searchString)
-                        : AddresseeLineEditManager::self()->completion()->substringCompletion(m_searchString);
+                        ? AddresseeLineEditManager::self()->completion()->allMatches(mSearchString)
+                        : AddresseeLineEditManager::self()->completion()->substringCompletion(mSearchString);
 
     //force items to be sorted by email
     items.sort();
@@ -332,7 +304,7 @@ const QStringList KPIM::AddresseeLineEditPrivate::adjustedCompletionItems(bool f
 
     if (AddresseeLineEditManager::self()->completion()->order() == KCompletion::Weighted) {
         // Sort the sections
-        QList<SourceWithWeight> sourcesAndWeights;
+        QVector<SourceWithWeight> sourcesAndWeights;
         const int numberOfCompletionSources(AddresseeLineEditManager::self()->completionSources.count());
         sourcesAndWeights.reserve(numberOfCompletionSources);
         for (int i = 0; i < numberOfCompletionSources; ++i) {
@@ -365,19 +337,19 @@ const QStringList KPIM::AddresseeLineEditPrivate::adjustedCompletionItems(bool f
 
 void AddresseeLineEditPrivate::updateSearchString()
 {
-    m_searchString = q->text();
+    mSearchString = q->text();
 
     int n = -1;
     bool inQuote = false;
-    const int searchStringLength = m_searchString.length();
+    const int searchStringLength = mSearchString.length();
     for (int i = 0; i < searchStringLength; ++i) {
-        const QChar searchChar = m_searchString.at(i);
+        const QChar searchChar = mSearchString.at(i);
         if (searchChar == QLatin1Char('"')) {
             inQuote = !inQuote;
         }
 
         if (searchChar == QLatin1Char('\\')
-            && (i + 1) < searchStringLength && m_searchString.at(i + 1) == QLatin1Char('"')) {
+            && (i + 1) < searchStringLength && mSearchString.at(i + 1) == QLatin1Char('"')) {
             ++i;
         }
 
@@ -387,7 +359,7 @@ void AddresseeLineEditPrivate::updateSearchString()
 
         if (i < searchStringLength
             && (searchChar == QLatin1Char(',')
-                || (m_useSemicolonAsSeparator && searchChar == QLatin1Char(';')))) {
+                || (mUseSemicolonAsSeparator && searchChar == QLatin1Char(';')))) {
             n = i;
         }
     }
@@ -395,51 +367,51 @@ void AddresseeLineEditPrivate::updateSearchString()
     if (n >= 0) {
         ++n; // Go past the ","
 
-        const int len = m_searchString.length();
+        const int len = mSearchString.length();
 
         // Increment past any whitespace...
-        while (n < len && m_searchString.at(n).isSpace()) {
+        while (n < len && mSearchString.at(n).isSpace()) {
             ++n;
         }
 
-        m_previousAddresses = m_searchString.left(n);
-        m_searchString = m_searchString.mid(n).trimmed();
+        mPreviousAddresses = mSearchString.left(n);
+        mSearchString = mSearchString.mid(n).trimmed();
     } else {
-        m_previousAddresses.clear();
+        mPreviousAddresses.clear();
     }
 }
 
 void AddresseeLineEditPrivate::slotTriggerDelayedQueries()
 {
-    const QString strSearch = m_searchString.trimmed();
+    const QString strSearch = mSearchString.trimmed();
     if (strSearch.size() <= 2) {
         return;
     }
 
-    if (m_enableBalooSearch) {
+    if (mEnableBalooSearch) {
         searchInBaloo();
     }
 
     // We send a contactsearch job through akonadi.
     // This not only searches baloo but also servers if remote search is enabled
-    if (m_enableAkonadiSearch) {
+    if (mEnableAkonadiSearch) {
         akonadiPerformSearch();
     }
 }
 
 void AddresseeLineEditPrivate::startSearches()
 {
-    if (!m_delayedQueryTimer.isActive()) {
-        m_delayedQueryTimer.start(50);
+    if (!mDelayedQueryTimer->isActive()) {
+        mDelayedQueryTimer->start(50);
     }
 }
 
 void AddresseeLineEditPrivate::akonadiPerformSearch()
 {
-    qCDebug(LIBKDEPIMAKONADI_LOG) << "searching akonadi with:" << m_searchString;
+    qCDebug(LIBKDEPIMAKONADI_LOG) << "searching akonadi with:" << mSearchString;
 
     // first, kill all job still in flight, they are no longer current
-    for (const QWeakPointer<Akonadi::Job> &job : qAsConst(AddresseeLineEditManager::self()->akonadiJobsInFlight)) {
+    for (const QPointer<Akonadi::Job> &job : qAsConst(AddresseeLineEditManager::self()->akonadiJobsInFlight)) {
         if (!job.isNull()) {
             job.data()->kill();
         }
@@ -449,7 +421,7 @@ void AddresseeLineEditPrivate::akonadiPerformSearch()
     // now start new jobs
     Akonadi::ContactSearchJob *contactJob = new Akonadi::ContactSearchJob(AddresseeLineEditManager::self()->akonadiSession());
     contactJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
-    contactJob->setQuery(Akonadi::ContactSearchJob::NameOrEmail, m_searchString,
+    contactJob->setQuery(Akonadi::ContactSearchJob::NameOrEmail, mSearchString,
                          Akonadi::ContactSearchJob::ContainsWordBoundaryMatch);
     connect(contactJob, &Akonadi::ItemSearchJob::itemsReceived,
             this, &AddresseeLineEditPrivate::slotAkonadiHandleItems);
@@ -458,7 +430,7 @@ void AddresseeLineEditPrivate::akonadiPerformSearch()
 
     Akonadi::ContactGroupSearchJob *groupJob = new Akonadi::ContactGroupSearchJob(AddresseeLineEditManager::self()->akonadiSession());
     groupJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
-    groupJob->setQuery(Akonadi::ContactGroupSearchJob::Name, m_searchString,
+    groupJob->setQuery(Akonadi::ContactGroupSearchJob::Name, mSearchString,
                        Akonadi::ContactGroupSearchJob::ContainsMatch);
     connect(contactJob, &Akonadi::ItemSearchJob::itemsReceived,
             this, &AddresseeLineEditPrivate::slotAkonadiHandleItems);
@@ -495,7 +467,7 @@ void AddresseeLineEditPrivate::akonadiHandlePending()
 
 void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
 {
-    m_lastSearchMode = ctrlT;
+    mLastSearchMode = ctrlT;
 
     const KCompletion::CompletionMode mode = q->completionMode();
 
@@ -510,7 +482,7 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
         const QStringList completions = adjustedCompletionItems(false);
 
         if (completions.count() == 1) {
-            q->setText(m_previousAddresses + completions.first().trimmed());
+            q->setText(mPreviousAddresses + completions.first().trimmed());
         }
 
         // Make sure the completion popup is closed if no matching items were found
@@ -523,13 +495,11 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
 
     switch (mode) {
     case KCompletion::CompletionPopupAuto:
-        if (m_searchString.isEmpty()) {
+        if (mSearchString.isEmpty()) {
             break;
         }
-    //else: fall-through to the CompletionPopup case
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        //else: fall-through to the CompletionPopup case
         Q_FALLTHROUGH();
-#endif
 
     case KCompletion::CompletionPopup:
     {
@@ -540,9 +510,9 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
 
     case KCompletion::CompletionShell:
     {
-        const QString match = AddresseeLineEditManager::self()->completion()->makeCompletion(m_searchString);
-        if (!match.isNull() && match != m_searchString) {
-            q->setText(m_previousAddresses + match);
+        const QString match = AddresseeLineEditManager::self()->completion()->makeCompletion(mSearchString);
+        if (!match.isNull() && match != mSearchString) {
+            q->setText(mPreviousAddresses + match);
             q->setModified(true);
             q->cursorAtEnd();
         }
@@ -554,41 +524,41 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
         //force autoSuggest in KLineEdit::keyPressed or setCompletedText will have no effect
         q->setCompletionMode(q->completionMode());
 
-        if (!m_searchString.isEmpty()) {
+        if (!mSearchString.isEmpty()) {
             //if only our \" is left, remove it since user has not typed it either
-            if (m_searchExtended && m_searchString == QLatin1String("\"")) {
-                m_searchExtended = false;
-                m_searchString.clear();
-                q->setText(m_previousAddresses);
+            if (mSearchExtended && mSearchString == QLatin1String("\"")) {
+                mSearchExtended = false;
+                mSearchString.clear();
+                q->setText(mPreviousAddresses);
                 break;
             }
 
-            QString match = AddresseeLineEditManager::self()->completion()->makeCompletion(m_searchString);
+            QString match = AddresseeLineEditManager::self()->completion()->makeCompletion(mSearchString);
 
             if (!match.isEmpty()) {
-                if (match != m_searchString) {
-                    const QString adds = m_previousAddresses + match;
+                if (match != mSearchString) {
+                    const QString adds = mPreviousAddresses + match;
                     q->callSetCompletedText(adds);
                 }
             } else {
-                if (!m_searchString.startsWith(QLatin1Char('\"'))) {
+                if (!mSearchString.startsWith(QLatin1Char('\"'))) {
                     //try with quoted text, if user has not type one already
-                    match = AddresseeLineEditManager::self()->completion()->makeCompletion(QLatin1String("\"") + m_searchString);
-                    if (!match.isEmpty() && match != m_searchString) {
-                        m_searchString = QLatin1String("\"") + m_searchString;
-                        m_searchExtended = true;
-                        q->setText(m_previousAddresses + m_searchString);
-                        q->callSetCompletedText(m_previousAddresses + match);
+                    match = AddresseeLineEditManager::self()->completion()->makeCompletion(QLatin1String("\"") + mSearchString);
+                    if (!match.isEmpty() && match != mSearchString) {
+                        mSearchString = QLatin1String("\"") + mSearchString;
+                        mSearchExtended = true;
+                        q->setText(mPreviousAddresses + mSearchString);
+                        q->callSetCompletedText(mPreviousAddresses + match);
                     }
-                } else if (m_searchExtended) {
+                } else if (mSearchExtended) {
                     //our added \" does not work anymore, remove it
-                    m_searchString = m_searchString.mid(1);
-                    m_searchExtended = false;
-                    q->setText(m_previousAddresses + m_searchString);
+                    mSearchString = mSearchString.mid(1);
+                    mSearchExtended = false;
+                    q->setText(mPreviousAddresses + mSearchString);
                     //now try again
-                    match = AddresseeLineEditManager::self()->completion()->makeCompletion(m_searchString);
-                    if (!match.isEmpty() && match != m_searchString) {
-                        const QString adds = m_previousAddresses + match;
+                    match = AddresseeLineEditManager::self()->completion()->makeCompletion(mSearchString);
+                    if (!match.isEmpty() && match != mSearchString) {
+                        const QString adds = mPreviousAddresses + match;
                         q->setCompletedText(adds);
                     }
                 }
@@ -597,7 +567,6 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
         break;
 
     case KCompletion::CompletionNone:
-    default: // fall through
         break;
     }
 }
@@ -611,7 +580,7 @@ void AddresseeLineEditPrivate::slotCompletion()
 
     updateSearchString();
     if (q->completionBox()) {
-        q->completionBox()->setCancelledText(m_searchString);
+        q->completionBox()->setCancelledText(mSearchString);
     }
 
     startSearches();
@@ -624,7 +593,7 @@ void AddresseeLineEditPrivate::slotPopupCompletion(const QString &completion)
     if (c.endsWith(QLatin1Char(')'))) {
         c = completion.mid(0, completion.lastIndexOf(QLatin1String(" ("))).trimmed();
     }
-    q->setText(m_previousAddresses + c);
+    q->setText(mPreviousAddresses + c);
     q->cursorAtEnd();
     updateSearchString();
     q->emitTextCompleted();
@@ -666,11 +635,11 @@ void AddresseeLineEditPrivate::slotLDAPSearchData(const KLDAP::LdapResult::List
         contact.setEmails(result.email);
         QString ou;
 
-        if (m_showOU) {
+        if (AddresseeLineEditManager::self()->showOU()) {
             const int depth = result.dn.depth();
             for (int i = 0; i < depth; ++i) {
                 const QString rdnStr = result.dn.rdnString(i);
-                if (rdnStr.startsWith(QStringLiteral("ou="), Qt::CaseInsensitive)) {
+                if (rdnStr.startsWith(QLatin1String("ou="), Qt::CaseInsensitive)) {
                     ou = rdnStr.mid(3);
                     break;
                 }
@@ -688,20 +657,20 @@ void AddresseeLineEditPrivate::slotLDAPSearchData(const KLDAP::LdapResult::List
     if ((q->hasFocus() || q->completionBox()->hasFocus())
         && q->completionMode() != KCompletion::CompletionNone
         && q->completionMode() != KCompletion::CompletionShell) {
-        q->setText(m_previousAddresses + m_searchString);
+        q->setText(mPreviousAddresses + mSearchString);
         // only complete again if the user didn't change the selection while
         // we were waiting; otherwise the completion box will be closed
         const QListWidgetItem *current = q->completionBox()->currentItem();
-        if (!current || m_searchString.trimmed() != current->text().trimmed()) {
-            doCompletion(m_lastSearchMode);
+        if (!current || mSearchString.trimmed() != current->text().trimmed()) {
+            doCompletion(mLastSearchMode);
         }
     }
 }
 
 void AddresseeLineEditPrivate::slotEditCompletionOrder()
 {
-    init(); // for AddresseeLineEditStatic::self()->ldapSearch
-    if (m_useCompletion) {
+    if (mUseCompletion) {
+        init(); // for AddresseeLineEditStatic::self()->ldapSearch
         QPointer<CompletionOrderEditor> dlg = new CompletionOrderEditor(AddresseeLineEditManager::self()->ldapSearch(), nullptr);
         if (dlg->exec()) {
             AddresseeLineEditManager::self()->updateCompletionOrder();
@@ -718,11 +687,11 @@ KLDAP::LdapClientSearch *AddresseeLineEditPrivate::ldapSearch()
 
 void AddresseeLineEditPrivate::slotUserCancelled(const QString &cancelText)
 {
-    if (AddresseeLineEditManager::self()->ldapSearch() && AddresseeLineEditManager::self()->addressLineEdit() == q) {
+    if (AddresseeLineEditManager::self()->addressLineEdit() == q) {
         AddresseeLineEditManager::self()->stopLDAPLookup();
     }
 
-    q->callUserCancelled(m_previousAddresses + cancelText);   // in KLineEdit
+    q->callUserCancelled(mPreviousAddresses + cancelText);   // in KLineEdit
 }
 
 void AddresseeLineEditPrivate::slotAkonadiHandleItems(const Akonadi::Item::List &items)
@@ -762,8 +731,8 @@ void AddresseeLineEditPrivate::slotAkonadiHandleItems(const Akonadi::Item::List
 
     if (!items.isEmpty()) {
         const QListWidgetItem *current = q->completionBox()->currentItem();
-        if (!current || m_searchString.trimmed() != current->text().trimmed()) {
-            doCompletion(m_lastSearchMode);
+        if (!current || mSearchString.trimmed() != current->text().trimmed()) {
+            doCompletion(mLastSearchMode);
         }
     }
 }
@@ -801,23 +770,24 @@ void AddresseeLineEditPrivate::slotAkonadiCollectionsReceived(
     akonadiHandlePending();
     // do completion
     const QListWidgetItem *current = q->completionBox()->currentItem();
-    if (!current || m_searchString.trimmed() != current->text().trimmed()) {
-        doCompletion(m_lastSearchMode);
+    if (!current || mSearchString.trimmed() != current->text().trimmed()) {
+        doCompletion(mLastSearchMode);
     }
 }
 
+void AddresseeLineEditPrivate::slotToggleExpandGroups(bool checked)
+{
+    AddresseeLineEditManager::self()->setAutoGroupExpand(checked);
+}
+
 void AddresseeLineEditPrivate::slotShowOUChanged(bool checked)
 {
-    if (checked != m_showOU) {
-        KConfigGroup group(KSharedConfig::openConfig(), "AddressLineEdit");
-        group.writeEntry("ShowOU", checked);
-        m_showOU = checked;
-    }
+    AddresseeLineEditManager::self()->setShowOU(checked);
 }
 
 void AddresseeLineEditPrivate::updateBalooBlackList()
 {
-    loadBalooBlackList();
+    AddresseeLineEditManager::self()->loadBalooBlackList();
     q->removeCompletionSource(i18nc("@title:group", "Contacts found in your data"));
     AddresseeLineEditManager::self()->setBalooCompletionSource(q->addCompletionSource(i18nc("@title:group", "Contacts found in your data"), -1));
 }
@@ -839,7 +809,7 @@ void AddresseeLineEditPrivate::setCanDeleteLineEdit(bool inprogressToConfigureCo
 
 KConfig *AddresseeLineEditPrivate::recentAddressConfig() const
 {
-    return m_recentAddressConfig;
+    return mRecentAddressConfig;
 }
 
 bool AddresseeLineEditPrivate::showRecentAddresses() const
@@ -849,7 +819,7 @@ bool AddresseeLineEditPrivate::showRecentAddresses() const
 
 void AddresseeLineEditPrivate::setRecentAddressConfig(KConfig *config)
 {
-    m_recentAddressConfig = config;
+    mRecentAddressConfig = config;
 }
 
 KContacts::ContactGroup::List AddresseeLineEditPrivate::groups() const
@@ -874,17 +844,12 @@ void AddresseeLineEditPrivate::setMightBeGroupJobs(const QList<KJob *> &mightBeG
 
 bool AddresseeLineEditPrivate::autoGroupExpand() const
 {
-    return mAutoGroupExpand;
+    return AddresseeLineEditManager::self()->autoGroupExpand();
 }
 
 void AddresseeLineEditPrivate::setAutoGroupExpand(bool autoGroupExpand)
 {
-    mAutoGroupExpand = autoGroupExpand;
-}
-
-QStringList AddresseeLineEditPrivate::balooBlackList() const
-{
-    return m_balooBlackList;
+    AddresseeLineEditManager::self()->setAutoGroupExpand(autoGroupExpand);
 }
 
 void AddresseeLineEditPrivate::setExpandIntern(bool b)
@@ -899,100 +864,82 @@ bool AddresseeLineEditPrivate::expandIntern() const
 
 bool AddresseeLineEditPrivate::useSemicolonAsSeparator() const
 {
-    return m_useSemicolonAsSeparator;
+    return mUseSemicolonAsSeparator;
 }
 
 void AddresseeLineEditPrivate::setUseSemicolonAsSeparator(bool useSemicolonAsSeparator)
 {
-    m_useSemicolonAsSeparator = useSemicolonAsSeparator;
+    mUseSemicolonAsSeparator = useSemicolonAsSeparator;
 }
 
 bool AddresseeLineEditPrivate::enableBalooSearch() const
 {
-    return m_enableBalooSearch;
+    return mEnableBalooSearch;
 }
 
 void AddresseeLineEditPrivate::setEnableBalooSearch(bool enableBalooSearch)
 {
-    m_enableBalooSearch = enableBalooSearch;
+    mEnableBalooSearch = enableBalooSearch;
 }
 
 bool AddresseeLineEditPrivate::enableAkonadiSearch() const
 {
-    return m_enableAkonadiSearch;
+    return mEnableAkonadiSearch;
 }
 
 void AddresseeLineEditPrivate::setEnableAkonadiSearch(bool enableAkonadiSearch)
 {
-    m_enableAkonadiSearch = enableAkonadiSearch;
+    mEnableAkonadiSearch = enableAkonadiSearch;
 }
 
 QString AddresseeLineEditPrivate::searchString() const
 {
-    return m_searchString;
+    return mSearchString;
 }
 
 void AddresseeLineEditPrivate::setSearchString(const QString &searchString)
 {
-    m_searchString = searchString;
+    mSearchString = searchString;
 }
 
 bool AddresseeLineEditPrivate::searchExtended() const
 {
-    return m_searchExtended;
+    return mSearchExtended;
 }
 
 void AddresseeLineEditPrivate::setSearchExtended(bool searchExtended)
 {
-    m_searchExtended = searchExtended;
+    mSearchExtended = searchExtended;
 }
 
 bool AddresseeLineEditPrivate::smartPaste() const
 {
-    return m_smartPaste;
+    return mSmartPaste;
 }
 
 void AddresseeLineEditPrivate::setSmartPaste(bool smartPaste)
 {
-    m_smartPaste = smartPaste;
+    mSmartPaste = smartPaste;
 }
 
 bool AddresseeLineEditPrivate::completionInitialized() const
 {
-    return m_completionInitialized;
-}
-
-void AddresseeLineEditPrivate::setCompletionInitialized(bool completionInitialized)
-{
-    m_completionInitialized = completionInitialized;
+    return mCompletionInitialized;
 }
 
 bool AddresseeLineEditPrivate::useCompletion() const
 {
-    return m_useCompletion;
+    return mUseCompletion;
 }
 
 void AddresseeLineEditPrivate::setUseCompletion(bool useCompletion)
 {
-    m_useCompletion = useCompletion;
+    mUseCompletion = useCompletion;
 }
 
 bool AddresseeLineEditPrivate::showOU() const
 {
-    return m_showOU;
-}
-
-void AddresseeLineEditPrivate::setShowOU(bool showOU)
-{
-    m_showOU = showOU;
-}
-
-void AddresseeLineEditPrivate::loadBalooBlackList()
-{
-    KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kpimbalooblacklist"));
-    KConfigGroup group(config, "AddressLineEdit");
-    m_balooBlackList = group.readEntry("BalooBackList", QStringList());
-    m_domainExcludeList = group.readEntry("ExcludeDomain", QStringList());
+    return AddresseeLineEditManager::self()->showOU();
 }
 
 void AddresseeLineEditPrivate::removeCompletionSource(const QString &source)
@@ -1039,4 +986,3 @@ void AddresseeLineEditPrivate::mightBeGroupJobsAdd(Akonadi::ContactGroupSearchJo
 {
     mMightBeGroupJobs.append(job);
 }
-}
